@@ -14,10 +14,10 @@
  */
 
 use crate::hash_string;
-use sha3::{Digest, Sha3_256};
+use sha2::{Digest, Sha256};
 
 hash_func!(
-    Sha3_256::new(),
-    |sha3256: &mut Sha3_256, buffer: &[u8]| sha3256.update(buffer),
-    |sha3256: Sha3_256| hash_string(&sha3256.finalize())
+    Sha256::new(),
+    |sha256: &mut Sha256, buffer: &[u8]| sha256.update(buffer),
+    |sha256: Sha256| { hash_string(&sha256.finalize()) }
 );
